@@ -74,7 +74,7 @@ CalcMPDynamics <- function(MPRecs, y, nyears, proyears, nsim,
                                                          nrow=(length((y + nyears):(nyears+proyears))),
                                                          ncol=nsim, byrow=TRUE)   # unchanged 
     
-  } else if (length(Rmaxlen) != nsim) {
+  } else if (length(MPRecs$Rmaxlen) != nsim) {
     stop("Rmaxlen recommmendation is not 'nsim' long.\n Does MP return Rmaxlen recommendation under all conditions?")
   } else {
     Rmaxlen_P[(y + nyears):(nyears+proyears),] <- matrix(MPRecs$Rmaxlen, 
@@ -423,10 +423,16 @@ MSYCalcs <- function(logapicF, MatAge, WtAge, MatureAge, VAge, maxage, R0, SRrel
   hs[hs>0.999] <- 0.999
   recK <- (4*hs)/(1-hs) # Goodyear compensation ratio
   reca <- recK/Egg0
-  if (SRrel ==1) recb <- (reca * Egg0 - 1)/(R0*Egg0) # BH SRR
-  if (SRrel ==2) recb <- log(reca*Egg0)/(R0*Egg0) # Ricker SRR
+  if (SRrel ==1) {
+    recb <- (reca * Egg0 - 1)/(R0*Egg0) # BH SRR
+    RelRec <- (reca * EggF-1)/(recb*EggF)
+  }
+  if (SRrel ==2) {
+    recb <- log(reca*Egg0)/(R0*Egg0) # Ricker SRR
+    RelRec <- (log(reca*EggF))/(recb*EggF)
+  }
 
-  RelRec <- (reca * EggF-1)/(recb*EggF)
+  
   RelRec[RelRec<0] <- 0
   
   Fa <- apicF*VAge
@@ -499,7 +505,7 @@ optMSY_eq <- function(x, M_ageArray, Wt_age, Mat_age, V, maxage, R0, SRrel, hs,
 #' @param nareas The number of spatial areas
 #' @param maxage The maximum age
 #' @param N Array of the numbers-at-age in population. Dimensions are nsim, maxage, nyears, nareas. 
-#' Only values from the first year (i.e N[,,1,]) are used, which is the current N-at-age.
+#' Only values from the first year (i.e `N[,,1,]`) are used, which is the current N-at-age.
 #' @param pyears The number of years to project forward. Equal to 'nyears' for optimizing for q.
 #' @param M_ageArray An array (dimensions nsim, maxage, nyears+proyears) with the natural mortality-at-age and year 
 #' @param Mat_age An array (dimensions nsim, maxage, proyears+nyears) with the proportion mature for each age-class
@@ -781,7 +787,7 @@ optQ <- function(logQ, depc, SSB0c, nareas, maxage, Ncurr, pyears, M_age, Asize_
 #' @param nareas The number of spatial areas
 #' @param maxage The maximum age
 #' @param N Array of the numbers-at-age in population. Dimensions are nsim, maxage, nyears, nareas. 
-#' Only values from the first year (i.e N[,,1,]) are used, which is the current N-at-age.
+#' Only values from the first year (i.e `N[,,1,]`) are used, which is the current N-at-age.
 #' @param pyears The number of years to project forward. Equal to 'nyears' for optimizing for q.
 #' @param M_ageArray An array (dimensions nsim, maxage, nyears+proyears) with the natural mortality-at-age and year
 #' @param Asize A matrix (dimensions nsim, nareas) of size of areas 
@@ -1007,7 +1013,7 @@ optMSY <- function(logFa, Asize_c, nareas, maxage, Ncurr, pyears, M_age,
 #' @param nareas The number of spatial areas
 #' @param maxage The maximum age
 #' @param N Array of the numbers-at-age in population. Dimensions are nsim, maxage, nyears, nareas. 
-#' Only values from the first year (i.e N[,,1,]) are used, which is the current N-at-age.
+#' Only values from the first year (i.e `N[,,1,]`) are used, which is the current N-at-age.
 #' @param pyears The number of years to project forward. Equal to 'nyears' for optimizing for q.
 #' @param M_ageArray An array (dimensions nsim, maxage, nyears+proyears) with the natural mortality-at-age and year 
 #' @param Mat_age An array (dimensions nsim, maxage, nyears+proyears) with the proportion mature for each age-class
